# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/entity/v1/entity.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n=github.com/metaprov/modelaapi/services/entity/v1/entity.proto\x12\x30github.com.metaprov.modelaapi.services.entity.v1\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x44github.com/metaprov/modelaapi/pkg/apis/data/v1alpha1/generated.proto\"\xf3\x01\n\x13ListEntitiesRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x61\n\x06labels\x18\x02 \x03(\x0b\x32Q.github.com.metaprov.modelaapi.services.entity.v1.ListEntitiesRequest.LabelsEntry\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\x12\n\npage_token\x18\x04 \x01(\t\x12\x10\n\x08order_by\x18\x05 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x83\x01\n\x14ListEntitiesResponse\x12R\n\x08\x65ntities\x18\x01 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.EntityList\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"c\n\x13\x43reateEntityRequest\x12L\n\x06\x65ntity\x18\x01 \x01(\x0b\x32<.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Entity\"\x16\n\x14\x43reateEntityResponse\"\x93\x01\n\x13UpdateEntityRequest\x12L\n\x06\x65ntity\x18\x01 \x01(\x0b\x32<.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Entity\x12.\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"\x16\n\x14UpdateEntityResponse\"c\n\x10GetEntityRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12.\n\nfield_mask\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"o\n\x11GetEntityResponse\x12L\n\x06\x65ntity\x18\x01 \x01(\x0b\x32<.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Entity\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"6\n\x13\x44\x65leteEntityRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x16\n\x14\x44\x65leteEntityResponse2\xf3\x07\n\rEntityService\x12\xbf\x01\n\x0cListEntities\x12\x45.github.com.metaprov.modelaapi.services.entity.v1.ListEntitiesRequest\x1a\x46.github.com.metaprov.modelaapi.services.entity.v1.ListEntitiesResponse\" \x82\xd3\xe4\x93\x02\x1a\x12\x18/v1/entities/{namespace}\x12\xb6\x01\n\x0c\x43reateEntity\x12\x45.github.com.metaprov.modelaapi.services.entity.v1.CreateEntityRequest\x1a\x46.github.com.metaprov.modelaapi.services.entity.v1.CreateEntityResponse\"\x17\x82\xd3\xe4\x93\x02\x11\"\x0c/v1/entities:\x01*\x12\xb1\x01\n\tGetEntity\x12\x42.github.com.metaprov.modelaapi.services.entity.v1.GetEntityRequest\x1a\x43.github.com.metaprov.modelaapi.services.entity.v1.GetEntityResponse\"\x1b\x82\xd3\xe4\x93\x02\x15\x12\x13/v1/entities/{name}\x12\xe9\x01\n\x0cUpdateEntity\x12\x45.github.com.metaprov.modelaapi.services.entity.v1.UpdateEntityRequest\x1a\x46.github.com.metaprov.modelaapi.services.entity.v1.UpdateEntityResponse\"J\x82\xd3\xe4\x93\x02\x44\x1a?/v1/entities/{entity.metadata.namespace}/{entity.metadata.name}:\x01*\x12\xc6\x01\n\x0c\x44\x65leteEntity\x12\x45.github.com.metaprov.modelaapi.services.entity.v1.DeleteEntityRequest\x1a\x46.github.com.metaprov.modelaapi.services.entity.v1.DeleteEntityResponse\"\'\x82\xd3\xe4\x93\x02!*\x1f/v1/entities/{namespace}/{name}B2Z0github.com/metaprov/modelaapi/services/entity/v1b\x06proto3')



_LISTENTITIESREQUEST = DESCRIPTOR.message_types_by_name['ListEntitiesRequest']
_LISTENTITIESREQUEST_LABELSENTRY = _LISTENTITIESREQUEST.nested_types_by_name['LabelsEntry']
_LISTENTITIESRESPONSE = DESCRIPTOR.message_types_by_name['ListEntitiesResponse']
_CREATEENTITYREQUEST = DESCRIPTOR.message_types_by_name['CreateEntityRequest']
_CREATEENTITYRESPONSE = DESCRIPTOR.message_types_by_name['CreateEntityResponse']
_UPDATEENTITYREQUEST = DESCRIPTOR.message_types_by_name['UpdateEntityRequest']
_UPDATEENTITYRESPONSE = DESCRIPTOR.message_types_by_name['UpdateEntityResponse']
_GETENTITYREQUEST = DESCRIPTOR.message_types_by_name['GetEntityRequest']
_GETENTITYRESPONSE = DESCRIPTOR.message_types_by_name['GetEntityResponse']
_DELETEENTITYREQUEST = DESCRIPTOR.message_types_by_name['DeleteEntityRequest']
_DELETEENTITYRESPONSE = DESCRIPTOR.message_types_by_name['DeleteEntityResponse']
ListEntitiesRequest = _reflection.GeneratedProtocolMessageType('ListEntitiesRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTENTITIESREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.entity.v1.entity_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.entity.v1.ListEntitiesRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTENTITIESREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.entity.v1.entity_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.entity.v1.ListEntitiesRequest)
  })
_sym_db.RegisterMessage(ListEntitiesRequest)
_sym_db.RegisterMessage(ListEntitiesRequest.LabelsEntry)

ListEntitiesResponse = _reflection.GeneratedProtocolMessageType('ListEntitiesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTENTITIESRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.entity.v1.entity_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.entity.v1.ListEntitiesResponse)
  })
_sym_db.RegisterMessage(ListEntitiesResponse)

CreateEntityRequest = _reflection.GeneratedProtocolMessageType('CreateEntityRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEENTITYREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.entity.v1.entity_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.entity.v1.CreateEntityRequest)
  })
_sym_db.RegisterMessage(CreateEntityRequest)

CreateEntityResponse = _reflection.GeneratedProtocolMessageType('CreateEntityResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEENTITYRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.entity.v1.entity_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.entity.v1.CreateEntityResponse)
  })
_sym_db.RegisterMessage(CreateEntityResponse)

UpdateEntityRequest = _reflection.GeneratedProtocolMessageType('UpdateEntityRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEENTITYREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.entity.v1.entity_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.entity.v1.UpdateEntityRequest)
  })
_sym_db.RegisterMessage(UpdateEntityRequest)

UpdateEntityResponse = _reflection.GeneratedProtocolMessageType('UpdateEntityResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEENTITYRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.entity.v1.entity_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.entity.v1.UpdateEntityResponse)
  })
_sym_db.RegisterMessage(UpdateEntityResponse)

GetEntityRequest = _reflection.GeneratedProtocolMessageType('GetEntityRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETENTITYREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.entity.v1.entity_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.entity.v1.GetEntityRequest)
  })
_sym_db.RegisterMessage(GetEntityRequest)

GetEntityResponse = _reflection.GeneratedProtocolMessageType('GetEntityResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETENTITYRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.entity.v1.entity_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.entity.v1.GetEntityResponse)
  })
_sym_db.RegisterMessage(GetEntityResponse)

DeleteEntityRequest = _reflection.GeneratedProtocolMessageType('DeleteEntityRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEENTITYREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.entity.v1.entity_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.entity.v1.DeleteEntityRequest)
  })
_sym_db.RegisterMessage(DeleteEntityRequest)

DeleteEntityResponse = _reflection.GeneratedProtocolMessageType('DeleteEntityResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEENTITYRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.entity.v1.entity_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.entity.v1.DeleteEntityResponse)
  })
_sym_db.RegisterMessage(DeleteEntityResponse)

_ENTITYSERVICE = DESCRIPTOR.services_by_name['EntityService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z0github.com/metaprov/modelaapi/services/entity/v1'
  _LISTENTITIESREQUEST_LABELSENTRY._options = None
  _LISTENTITIESREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _ENTITYSERVICE.methods_by_name['ListEntities']._options = None
  _ENTITYSERVICE.methods_by_name['ListEntities']._serialized_options = b'\202\323\344\223\002\032\022\030/v1/entities/{namespace}'
  _ENTITYSERVICE.methods_by_name['CreateEntity']._options = None
  _ENTITYSERVICE.methods_by_name['CreateEntity']._serialized_options = b'\202\323\344\223\002\021\"\014/v1/entities:\001*'
  _ENTITYSERVICE.methods_by_name['GetEntity']._options = None
  _ENTITYSERVICE.methods_by_name['GetEntity']._serialized_options = b'\202\323\344\223\002\025\022\023/v1/entities/{name}'
  _ENTITYSERVICE.methods_by_name['UpdateEntity']._options = None
  _ENTITYSERVICE.methods_by_name['UpdateEntity']._serialized_options = b'\202\323\344\223\002D\032?/v1/entities/{entity.metadata.namespace}/{entity.metadata.name}:\001*'
  _ENTITYSERVICE.methods_by_name['DeleteEntity']._options = None
  _ENTITYSERVICE.methods_by_name['DeleteEntity']._serialized_options = b'\202\323\344\223\002!*\037/v1/entities/{namespace}/{name}'
  _LISTENTITIESREQUEST._serialized_start=250
  _LISTENTITIESREQUEST._serialized_end=493
  _LISTENTITIESREQUEST_LABELSENTRY._serialized_start=448
  _LISTENTITIESREQUEST_LABELSENTRY._serialized_end=493
  _LISTENTITIESRESPONSE._serialized_start=496
  _LISTENTITIESRESPONSE._serialized_end=627
  _CREATEENTITYREQUEST._serialized_start=629
  _CREATEENTITYREQUEST._serialized_end=728
  _CREATEENTITYRESPONSE._serialized_start=730
  _CREATEENTITYRESPONSE._serialized_end=752
  _UPDATEENTITYREQUEST._serialized_start=755
  _UPDATEENTITYREQUEST._serialized_end=902
  _UPDATEENTITYRESPONSE._serialized_start=904
  _UPDATEENTITYRESPONSE._serialized_end=926
  _GETENTITYREQUEST._serialized_start=928
  _GETENTITYREQUEST._serialized_end=1027
  _GETENTITYRESPONSE._serialized_start=1029
  _GETENTITYRESPONSE._serialized_end=1140
  _DELETEENTITYREQUEST._serialized_start=1142
  _DELETEENTITYREQUEST._serialized_end=1196
  _DELETEENTITYRESPONSE._serialized_start=1198
  _DELETEENTITYRESPONSE._serialized_end=1220
  _ENTITYSERVICE._serialized_start=1223
  _ENTITYSERVICE._serialized_end=2234
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from github.com.metaprov.modelaapi.services.todo.v1 import todo_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_todo_dot_v1_dot_todo__pb2


class TodoServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListTodos = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.todo.v1.TodoService/ListTodos',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_todo_dot_v1_dot_todo__pb2.ListTodosRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_todo_dot_v1_dot_todo__pb2.ListTodosResponse.FromString,
                )
        self.CreateTodo = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.todo.v1.TodoService/CreateTodo',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_todo_dot_v1_dot_todo__pb2.CreateTodoRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_todo_dot_v1_dot_todo__pb2.CreateTodoResponse.FromString,
                )
        self.GetTodo = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.todo.v1.TodoService/GetTodo',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_todo_dot_v1_dot_todo__pb2.GetTodoRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_todo_dot_v1_dot_todo__pb2.GetTodoResponse.FromString,
                )
        self.UpdateTodo = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.todo.v1.TodoService/UpdateTodo',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_todo_dot_v1_dot_todo__pb2.UpdateTodoRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_todo_dot_v1_dot_todo__pb2.UpdateTodoResponse.FromString,
                )
        self.DeleteTodo = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.todo.v1.TodoService/DeleteTodo',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_todo_dot_v1_dot_todo__pb2.DeleteTodoRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_todo_dot_v1_dot_todo__pb2.DeleteTodoResponse.FromString,
                )


class TodoServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListTodos(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateTodo(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTodo(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateTodo(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteTodo(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_TodoServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListTodos': grpc.unary_unary_rpc_method_handler(
                    servicer.ListTodos,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_todo_dot_v1_dot_todo__pb2.ListTodosRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_todo_dot_v1_dot_todo__pb2.ListTodosResponse.SerializeToString,
            ),
            'CreateTodo': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateTodo,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_todo_dot_v1_dot_todo__pb2.CreateTodoRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_todo_dot_v1_dot_todo__pb2.CreateTodoResponse.SerializeToString,
            ),
            'GetTodo': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTodo,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_todo_dot_v1_dot_todo__pb2.GetTodoRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_todo_dot_v1_dot_todo__pb2.GetTodoResponse.SerializeToString,
            ),
            'UpdateTodo': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateTodo,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_todo_dot_v1_dot_todo__pb2.UpdateTodoRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_todo_dot_v1_dot_todo__pb2.UpdateTodoResponse.SerializeToString,
            ),
            'DeleteTodo': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteTodo,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_todo_dot_v1_dot_todo__pb2.DeleteTodoRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_todo_dot_v1_dot_todo__pb2.DeleteTodoResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'github.com.metaprov.modelaapi.services.todo.v1.TodoService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class TodoService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListTodos(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.todo.v1.TodoService/ListTodos',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_todo_dot_v1_dot_todo__pb2.ListTodosRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_todo_dot_v1_dot_todo__pb2.ListTodosResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateTodo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.todo.v1.TodoService/CreateTodo',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_todo_dot_v1_dot_todo__pb2.CreateTodoRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_todo_dot_v1_dot_todo__pb2.CreateTodoResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetTodo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.todo.v1.TodoService/GetTodo',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_todo_dot_v1_dot_todo__pb2.GetTodoRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_todo_dot_v1_dot_todo__pb2.GetTodoResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateTodo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.todo.v1.TodoService/UpdateTodo',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_todo_dot_v1_dot_todo__pb2.UpdateTodoRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_todo_dot_v1_dot_todo__pb2.UpdateTodoResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteTodo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.todo.v1.TodoService/DeleteTodo',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_todo_dot_v1_dot_todo__pb2.DeleteTodoRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_todo_dot_v1_dot_todo__pb2.DeleteTodoResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from github.com.metaprov.modelaapi.services.datapipelinerun.v1 import datapipelinerun_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipelinerun_dot_v1_dot_datapipelinerun__pb2


class DataPipelineRunServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListDataPipelineRuns = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.datapipelinerun.v1.DataPipelineRunService/ListDataPipelineRuns',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipelinerun_dot_v1_dot_datapipelinerun__pb2.ListDataPipelineRunRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipelinerun_dot_v1_dot_datapipelinerun__pb2.ListDataPipelineRunResponse.FromString,
                )
        self.CreateDataPipelineRun = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.datapipelinerun.v1.DataPipelineRunService/CreateDataPipelineRun',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipelinerun_dot_v1_dot_datapipelinerun__pb2.CreateDataPipelineRunRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipelinerun_dot_v1_dot_datapipelinerun__pb2.CreateDataPipelineRunResponse.FromString,
                )
        self.GetDataPipelineRun = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.datapipelinerun.v1.DataPipelineRunService/GetDataPipelineRun',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipelinerun_dot_v1_dot_datapipelinerun__pb2.GetDataPipelineRunRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipelinerun_dot_v1_dot_datapipelinerun__pb2.GetDataPipelineRunResponse.FromString,
                )
        self.UpdateDataPipelineRun = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.datapipelinerun.v1.DataPipelineRunService/UpdateDataPipelineRun',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipelinerun_dot_v1_dot_datapipelinerun__pb2.UpdateDataPipelineRunRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipelinerun_dot_v1_dot_datapipelinerun__pb2.UpdateDataPipelineRunResponse.FromString,
                )
        self.DeleteDataPipelineRun = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.datapipelinerun.v1.DataPipelineRunService/DeleteDataPipelineRun',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipelinerun_dot_v1_dot_datapipelinerun__pb2.DeleteDataPipelineRunRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipelinerun_dot_v1_dot_datapipelinerun__pb2.DeleteDataPipelineRunResponse.FromString,
                )
        self.AbortDataPipelineRun = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.datapipelinerun.v1.DataPipelineRunService/AbortDataPipelineRun',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipelinerun_dot_v1_dot_datapipelinerun__pb2.AbortDataPipelineRunRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipelinerun_dot_v1_dot_datapipelinerun__pb2.AbortDataPipelineRunResponse.FromString,
                )
        self.PauseDataPipelineRun = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.datapipelinerun.v1.DataPipelineRunService/PauseDataPipelineRun',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipelinerun_dot_v1_dot_datapipelinerun__pb2.PauseDataPipelineRunRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipelinerun_dot_v1_dot_datapipelinerun__pb2.PauseDataPipelineRunResponse.FromString,
                )
        self.ResumeDataPipelineRun = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.datapipelinerun.v1.DataPipelineRunService/ResumeDataPipelineRun',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipelinerun_dot_v1_dot_datapipelinerun__pb2.ResumeDataPipelineRunRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipelinerun_dot_v1_dot_datapipelinerun__pb2.ResumeDataPipelineRunResponse.FromString,
                )


class DataPipelineRunServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListDataPipelineRuns(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateDataPipelineRun(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDataPipelineRun(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateDataPipelineRun(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteDataPipelineRun(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AbortDataPipelineRun(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PauseDataPipelineRun(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ResumeDataPipelineRun(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_DataPipelineRunServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListDataPipelineRuns': grpc.unary_unary_rpc_method_handler(
                    servicer.ListDataPipelineRuns,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipelinerun_dot_v1_dot_datapipelinerun__pb2.ListDataPipelineRunRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipelinerun_dot_v1_dot_datapipelinerun__pb2.ListDataPipelineRunResponse.SerializeToString,
            ),
            'CreateDataPipelineRun': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateDataPipelineRun,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipelinerun_dot_v1_dot_datapipelinerun__pb2.CreateDataPipelineRunRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipelinerun_dot_v1_dot_datapipelinerun__pb2.CreateDataPipelineRunResponse.SerializeToString,
            ),
            'GetDataPipelineRun': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDataPipelineRun,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipelinerun_dot_v1_dot_datapipelinerun__pb2.GetDataPipelineRunRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipelinerun_dot_v1_dot_datapipelinerun__pb2.GetDataPipelineRunResponse.SerializeToString,
            ),
            'UpdateDataPipelineRun': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateDataPipelineRun,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipelinerun_dot_v1_dot_datapipelinerun__pb2.UpdateDataPipelineRunRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipelinerun_dot_v1_dot_datapipelinerun__pb2.UpdateDataPipelineRunResponse.SerializeToString,
            ),
            'DeleteDataPipelineRun': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteDataPipelineRun,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipelinerun_dot_v1_dot_datapipelinerun__pb2.DeleteDataPipelineRunRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipelinerun_dot_v1_dot_datapipelinerun__pb2.DeleteDataPipelineRunResponse.SerializeToString,
            ),
            'AbortDataPipelineRun': grpc.unary_unary_rpc_method_handler(
                    servicer.AbortDataPipelineRun,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipelinerun_dot_v1_dot_datapipelinerun__pb2.AbortDataPipelineRunRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipelinerun_dot_v1_dot_datapipelinerun__pb2.AbortDataPipelineRunResponse.SerializeToString,
            ),
            'PauseDataPipelineRun': grpc.unary_unary_rpc_method_handler(
                    servicer.PauseDataPipelineRun,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipelinerun_dot_v1_dot_datapipelinerun__pb2.PauseDataPipelineRunRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipelinerun_dot_v1_dot_datapipelinerun__pb2.PauseDataPipelineRunResponse.SerializeToString,
            ),
            'ResumeDataPipelineRun': grpc.unary_unary_rpc_method_handler(
                    servicer.ResumeDataPipelineRun,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipelinerun_dot_v1_dot_datapipelinerun__pb2.ResumeDataPipelineRunRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipelinerun_dot_v1_dot_datapipelinerun__pb2.ResumeDataPipelineRunResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'github.com.metaprov.modelaapi.services.datapipelinerun.v1.DataPipelineRunService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class DataPipelineRunService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListDataPipelineRuns(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.datapipelinerun.v1.DataPipelineRunService/ListDataPipelineRuns',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipelinerun_dot_v1_dot_datapipelinerun__pb2.ListDataPipelineRunRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipelinerun_dot_v1_dot_datapipelinerun__pb2.ListDataPipelineRunResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateDataPipelineRun(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.datapipelinerun.v1.DataPipelineRunService/CreateDataPipelineRun',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipelinerun_dot_v1_dot_datapipelinerun__pb2.CreateDataPipelineRunRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipelinerun_dot_v1_dot_datapipelinerun__pb2.CreateDataPipelineRunResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDataPipelineRun(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.datapipelinerun.v1.DataPipelineRunService/GetDataPipelineRun',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipelinerun_dot_v1_dot_datapipelinerun__pb2.GetDataPipelineRunRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipelinerun_dot_v1_dot_datapipelinerun__pb2.GetDataPipelineRunResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateDataPipelineRun(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.datapipelinerun.v1.DataPipelineRunService/UpdateDataPipelineRun',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipelinerun_dot_v1_dot_datapipelinerun__pb2.UpdateDataPipelineRunRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipelinerun_dot_v1_dot_datapipelinerun__pb2.UpdateDataPipelineRunResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteDataPipelineRun(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.datapipelinerun.v1.DataPipelineRunService/DeleteDataPipelineRun',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipelinerun_dot_v1_dot_datapipelinerun__pb2.DeleteDataPipelineRunRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipelinerun_dot_v1_dot_datapipelinerun__pb2.DeleteDataPipelineRunResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AbortDataPipelineRun(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.datapipelinerun.v1.DataPipelineRunService/AbortDataPipelineRun',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipelinerun_dot_v1_dot_datapipelinerun__pb2.AbortDataPipelineRunRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipelinerun_dot_v1_dot_datapipelinerun__pb2.AbortDataPipelineRunResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PauseDataPipelineRun(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.datapipelinerun.v1.DataPipelineRunService/PauseDataPipelineRun',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipelinerun_dot_v1_dot_datapipelinerun__pb2.PauseDataPipelineRunRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipelinerun_dot_v1_dot_datapipelinerun__pb2.PauseDataPipelineRunResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ResumeDataPipelineRun(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.datapipelinerun.v1.DataPipelineRunService/ResumeDataPipelineRun',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipelinerun_dot_v1_dot_datapipelinerun__pb2.ResumeDataPipelineRunRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datapipelinerun_dot_v1_dot_datapipelinerun__pb2.ResumeDataPipelineRunResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/pkg/apis/team/v1alpha1/generated.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from k8s.io.api.core.v1 import generated_pb2 as k8s_dot_io_dot_api_dot_core_dot_v1_dot_generated__pb2
from k8s.io.apimachinery.pkg.apis.meta.v1 import generated_pb2 as k8s_dot_io_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1_dot_generated__pb2
from k8s.io.apimachinery.pkg.runtime import generated_pb2 as k8s_dot_io_dot_apimachinery_dot_pkg_dot_runtime_dot_generated__pb2
from k8s.io.apimachinery.pkg.runtime.schema import generated_pb2 as k8s_dot_io_dot_apimachinery_dot_pkg_dot_runtime_dot_schema_dot_generated__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nDgithub.com/metaprov/modelaapi/pkg/apis/team/v1alpha1/generated.proto\x12\x34github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1\x1a\"k8s.io/api/core/v1/generated.proto\x1a\x34k8s.io/apimachinery/pkg/apis/meta/v1/generated.proto\x1a/k8s.io/apimachinery/pkg/runtime/generated.proto\x1a\x36k8s.io/apimachinery/pkg/runtime/schema/generated.proto\"n\n\rCheckListItem\x12\x13\n\x0binstruction\x18\x01 \x01(\t\x12\x0f\n\x07\x65nabled\x18\x02 \x01(\x08\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x11\n\tcondition\x18\x04 \x01(\t\x12\x12\n\nattachment\x18\x05 \x01(\t\"\x92\x02\n\x07\x43omment\x12\n\n\x02id\x18\x01 \x01(\t\x12\x36\n\tauthorRef\x18\x02 \x01(\x0b\x32#.k8s.io.api.core.v1.ObjectReference\x12\x0f\n\x07replyTo\x18\x03 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x04 \x01(\t\x12<\n\x08postedAt\x18\x05 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x0c\n\x04sent\x18\x06 \x01(\x08\x12\x0e\n\x06pinned\x18\x07 \x01(\x08\x12\x19\n\x11replyIndicationID\x18\x08 \x01(\t\x12\x10\n\x08imageURL\x18\t \x01(\t\x12\x18\n\x10\x61\x63\x63ountMentionID\x18\n \x01(\t\"\xf3\x01\n\x07Meeting\x12\x42\n\x08metadata\x18\x01 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12O\n\x04spec\x18\x02 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.MeetingSpec\x12S\n\x06status\x18\x03 \x01(\x0b\x32\x43.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.MeetingStatus\"\x99\x01\n\x10MeetingCondition\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0e\n\x06status\x18\x02 \x01(\t\x12\x46\n\x12lastTransitionTime\x18\x03 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x0e\n\x06reason\x18\x04 \x01(\t\x12\x0f\n\x07message\x18\x05 \x01(\t\"\x9d\x01\n\x0bMeetingList\x12@\n\x08metadata\x18\x01 \x01(\x0b\x32..k8s.io.apimachinery.pkg.apis.meta.v1.ListMeta\x12L\n\x05items\x18\x02 \x03(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.Meeting\"\x9d\x02\n\x0bMeetingSpec\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x0e\n\x06\x61genda\x18\x02 \x01(\t\x12\x36\n\tentityRef\x18\x03 \x01(\x0b\x32#.k8s.io.api.core.v1.ObjectReference\x12\x14\n\x0cnotifierName\x18\x04 \x01(\t\x12\x14\n\x0cparticipants\x18\x05 \x03(\t\x12\x0f\n\x07\x66lagged\x18\x06 \x01(\x08\x12<\n\x08reminder\x18\x07 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x36\n\ttenantRef\x18\x08 \x01(\x0b\x32#.k8s.io.api.core.v1.ObjectReference\"\xfb\x01\n\rMeetingStatus\x12\r\n\x05phase\x18\x01 \x01(\t\x12\x1a\n\x12observedGeneration\x18\x02 \x01(\x03\x12\r\n\x05notes\x18\x04 \x01(\t\x12\x13\n\x0b\x61\x63tionItems\x18\x05 \x01(\t\x12?\n\x0blastUpdated\x18\x06 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12Z\n\nconditions\x18\x07 \x03(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.MeetingCondition\"\xfc\x01\n\nPostMortem\x12\x42\n\x08metadata\x18\x01 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12R\n\x04spec\x18\x02 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.PostMortemSpec\x12V\n\x06status\x18\x03 \x01(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.PostMortemStatus\"\x9c\x01\n\x13PostMortemCondition\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0e\n\x06status\x18\x02 \x01(\t\x12\x46\n\x12lastTransitionTime\x18\x03 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x0e\n\x06reason\x18\x04 \x01(\t\x12\x0f\n\x07message\x18\x05 \x01(\t\"\xa3\x01\n\x0ePostMortemList\x12@\n\x08metadata\x18\x01 \x01(\x0b\x32..k8s.io.apimachinery.pkg.apis.meta.v1.ListMeta\x12O\n\x05items\x18\x02 \x03(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.PostMortem\"\xe3\x03\n\x0ePostMortemSpec\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x36\n\tentityRef\x18\x02 \x01(\x0b\x32#.k8s.io.api.core.v1.ObjectReference\x12\x38\n\x0blocationRef\x18\x03 \x01(\x0b\x32#.k8s.io.api.core.v1.ObjectReference\x12\x36\n\thandledBy\x18\x04 \x03(\x0b\x32#.k8s.io.api.core.v1.ObjectReference\x12P\n\x05\x61lert\x18\x05 \x03(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.RaisedAlert\x12U\n\x08timeline\x18\x06 \x03(\x0b\x32\x43.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.TimeLineEvent\x12\x11\n\trootCause\x18\x07 \x01(\t\x12\x0f\n\x07summary\x18\x08 \x01(\t\x12\r\n\x05owner\x18\t \x01(\t\x12\x36\n\ttenantRef\x18\n \x01(\x0b\x32#.k8s.io.api.core.v1.ObjectReference\"\xce\x01\n\x10PostMortemStatus\x12\x1a\n\x12observedGeneration\x18\x01 \x01(\x03\x12?\n\x0blastUpdated\x18\x02 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12]\n\nconditions\x18\x03 \x03(\x0b\x32I.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.PostMortemCondition\"S\n\x0bRaisedAlert\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x36\n\x02\x61t\x18\x02 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\"\xf0\x01\n\x06Review\x12\x42\n\x08metadata\x18\x01 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12N\n\x04spec\x18\x02 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.ReviewSpec\x12R\n\x06status\x18\x03 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.ReviewStatus\"\x98\x01\n\x0fReviewCondition\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0e\n\x06status\x18\x02 \x01(\t\x12\x46\n\x12lastTransitionTime\x18\x03 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x0e\n\x06reason\x18\x04 \x01(\t\x12\x0f\n\x07message\x18\x05 \x01(\t\"\x9b\x01\n\nReviewList\x12@\n\x08metadata\x18\x01 \x01(\x0b\x32..k8s.io.apimachinery.pkg.apis.meta.v1.ListMeta\x12K\n\x05items\x18\x02 \x03(\x0b\x32<.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.Review\"\xf2\x01\n\nReviewSpec\x12\x36\n\tentityRef\x18\x01 \x01(\x0b\x32#.k8s.io.api.core.v1.ObjectReference\x12O\n\x08messages\x18\x02 \x03(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.Comment\x12\r\n\x05owner\x18\x03 \x01(\t\x12\x14\n\x0cnotifierName\x18\x04 \x01(\t\x12\x36\n\ttenantRef\x18\x05 \x01(\x0b\x32#.k8s.io.api.core.v1.ObjectReference\"\xc6\x01\n\x0cReviewStatus\x12?\n\x0blastUpdated\x18\x01 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x1a\n\x12observedGeneration\x18\x02 \x01(\x03\x12Y\n\nconditions\x18\x03 \x03(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.ReviewCondition\"\xf3\x01\n\x07RunBook\x12\x42\n\x08metadata\x18\x01 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12O\n\x04spec\x18\x02 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.RunBookSpec\x12S\n\x06status\x18\x03 \x01(\x0b\x32\x43.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.RunBookStatus\"\xdd\x01\n\x10RunBookCondition\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0e\n\x06status\x18\x02 \x01(\t\x12\x42\n\x0elastUpdateTime\x18\x03 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x46\n\x12lastTransitionTime\x18\x04 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x0e\n\x06reason\x18\x05 \x01(\t\x12\x0f\n\x07message\x18\x06 \x01(\t\"\x9d\x01\n\x0bRunBookList\x12@\n\x08metadata\x18\x01 \x01(\x0b\x32..k8s.io.apimachinery.pkg.apis.meta.v1.ListMeta\x12L\n\x05items\x18\x02 \x03(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.RunBook\"\xb1\x02\n\x0bRunBookSpec\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x36\n\tentityRef\x18\x02 \x01(\x0b\x32#.k8s.io.api.core.v1.ObjectReference\x12\x36\n\tauthorRef\x18\x03 \x01(\x0b\x32#.k8s.io.api.core.v1.ObjectReference\x12V\n\tchecklist\x18\x04 \x03(\x0b\x32\x43.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.CheckListItem\x12\r\n\x05owner\x18\x05 \x01(\t\x12\x36\n\ttenantRef\x18\x06 \x01(\x0b\x32#.k8s.io.api.core.v1.ObjectReference\"\xc8\x01\n\rRunBookStatus\x12\x1a\n\x12observedGeneration\x18\x01 \x01(\x03\x12?\n\x0blastUpdated\x18\x02 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12Z\n\nconditions\x18\x03 \x03(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.RunBookCondition\"X\n\rTimeLineEvent\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\t\x12\x36\n\x02\x61t\x18\x02 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\"\xea\x01\n\x04Todo\x12\x42\n\x08metadata\x18\x01 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12L\n\x04spec\x18\x02 \x01(\x0b\x32>.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.TodoSpec\x12P\n\x06status\x18\x03 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.TodoStatus\"\x96\x01\n\rTodoCondition\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0e\n\x06status\x18\x02 \x01(\t\x12\x46\n\x12lastTransitionTime\x18\x03 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x0e\n\x06reason\x18\x04 \x01(\t\x12\x0f\n\x07message\x18\x05 \x01(\t\"\x97\x01\n\x08TodoList\x12@\n\x08metadata\x18\x01 \x01(\x0b\x32..k8s.io.apimachinery.pkg.apis.meta.v1.ListMeta\x12I\n\x05items\x18\x02 \x03(\x0b\x32:.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.Todo\"\xe7\x02\n\x08TodoSpec\x12\x0c\n\x04task\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x36\n\tentityRef\x18\x03 \x01(\x0b\x32#.k8s.io.api.core.v1.ObjectReference\x12\x14\n\x0cnotifierName\x18\x04 \x01(\t\x12\x12\n\nassignedTo\x18\x05 \x01(\t\x12\x0f\n\x07\x66lagged\x18\x06 \x01(\x08\x12<\n\x08reminder\x18\x07 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12;\n\x07\x64ueDate\x18\x08 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x12\n\nparentTask\x18\t \x01(\t\x12\x36\n\ttenantRef\x18\n \x01(\x0b\x32#.k8s.io.api.core.v1.ObjectReference\"\xd1\x01\n\nTodoStatus\x12\r\n\x05phase\x18\x01 \x01(\t\x12\x1a\n\x12observedGeneration\x18\x02 \x01(\x03\x12?\n\x0blastUpdated\x18\x06 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12W\n\nconditions\x18\x03 \x03(\x0b\x32\x43.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.TodoConditionB6Z4github.com/metaprov/modelaapi/pkg/apis/team/v1alpha1')



_CHECKLISTITEM = DESCRIPTOR.message_types_by_name['CheckListItem']
_COMMENT = DESCRIPTOR.message_types_by_name['Comment']
_MEETING = DESCRIPTOR.message_types_by_name['Meeting']
_MEETINGCONDITION = DESCRIPTOR.message_types_by_name['MeetingCondition']
_MEETINGLIST = DESCRIPTOR.message_types_by_name['MeetingList']
_MEETINGSPEC = DESCRIPTOR.message_types_by_name['MeetingSpec']
_MEETINGSTATUS = DESCRIPTOR.message_types_by_name['MeetingStatus']
_POSTMORTEM = DESCRIPTOR.message_types_by_name['PostMortem']
_POSTMORTEMCONDITION = DESCRIPTOR.message_types_by_name['PostMortemCondition']
_POSTMORTEMLIST = DESCRIPTOR.message_types_by_name['PostMortemList']
_POSTMORTEMSPEC = DESCRIPTOR.message_types_by_name['PostMortemSpec']
_POSTMORTEMSTATUS = DESCRIPTOR.message_types_by_name['PostMortemStatus']
_RAISEDALERT = DESCRIPTOR.message_types_by_name['RaisedAlert']
_REVIEW = DESCRIPTOR.message_types_by_name['Review']
_REVIEWCONDITION = DESCRIPTOR.message_types_by_name['ReviewCondition']
_REVIEWLIST = DESCRIPTOR.message_types_by_name['ReviewList']
_REVIEWSPEC = DESCRIPTOR.message_types_by_name['ReviewSpec']
_REVIEWSTATUS = DESCRIPTOR.message_types_by_name['ReviewStatus']
_RUNBOOK = DESCRIPTOR.message_types_by_name['RunBook']
_RUNBOOKCONDITION = DESCRIPTOR.message_types_by_name['RunBookCondition']
_RUNBOOKLIST = DESCRIPTOR.message_types_by_name['RunBookList']
_RUNBOOKSPEC = DESCRIPTOR.message_types_by_name['RunBookSpec']
_RUNBOOKSTATUS = DESCRIPTOR.message_types_by_name['RunBookStatus']
_TIMELINEEVENT = DESCRIPTOR.message_types_by_name['TimeLineEvent']
_TODO = DESCRIPTOR.message_types_by_name['Todo']
_TODOCONDITION = DESCRIPTOR.message_types_by_name['TodoCondition']
_TODOLIST = DESCRIPTOR.message_types_by_name['TodoList']
_TODOSPEC = DESCRIPTOR.message_types_by_name['TodoSpec']
_TODOSTATUS = DESCRIPTOR.message_types_by_name['TodoStatus']
CheckListItem = _reflection.GeneratedProtocolMessageType('CheckListItem', (_message.Message,), {
  'DESCRIPTOR' : _CHECKLISTITEM,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.CheckListItem)
  })
_sym_db.RegisterMessage(CheckListItem)

Comment = _reflection.GeneratedProtocolMessageType('Comment', (_message.Message,), {
  'DESCRIPTOR' : _COMMENT,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.Comment)
  })
_sym_db.RegisterMessage(Comment)

Meeting = _reflection.GeneratedProtocolMessageType('Meeting', (_message.Message,), {
  'DESCRIPTOR' : _MEETING,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.Meeting)
  })
_sym_db.RegisterMessage(Meeting)

MeetingCondition = _reflection.GeneratedProtocolMessageType('MeetingCondition', (_message.Message,), {
  'DESCRIPTOR' : _MEETINGCONDITION,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.MeetingCondition)
  })
_sym_db.RegisterMessage(MeetingCondition)

MeetingList = _reflection.GeneratedProtocolMessageType('MeetingList', (_message.Message,), {
  'DESCRIPTOR' : _MEETINGLIST,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.MeetingList)
  })
_sym_db.RegisterMessage(MeetingList)

MeetingSpec = _reflection.GeneratedProtocolMessageType('MeetingSpec', (_message.Message,), {
  'DESCRIPTOR' : _MEETINGSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.MeetingSpec)
  })
_sym_db.RegisterMessage(MeetingSpec)

MeetingStatus = _reflection.GeneratedProtocolMessageType('MeetingStatus', (_message.Message,), {
  'DESCRIPTOR' : _MEETINGSTATUS,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.MeetingStatus)
  })
_sym_db.RegisterMessage(MeetingStatus)

PostMortem = _reflection.GeneratedProtocolMessageType('PostMortem', (_message.Message,), {
  'DESCRIPTOR' : _POSTMORTEM,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.PostMortem)
  })
_sym_db.RegisterMessage(PostMortem)

PostMortemCondition = _reflection.GeneratedProtocolMessageType('PostMortemCondition', (_message.Message,), {
  'DESCRIPTOR' : _POSTMORTEMCONDITION,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.PostMortemCondition)
  })
_sym_db.RegisterMessage(PostMortemCondition)

PostMortemList = _reflection.GeneratedProtocolMessageType('PostMortemList', (_message.Message,), {
  'DESCRIPTOR' : _POSTMORTEMLIST,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.PostMortemList)
  })
_sym_db.RegisterMessage(PostMortemList)

PostMortemSpec = _reflection.GeneratedProtocolMessageType('PostMortemSpec', (_message.Message,), {
  'DESCRIPTOR' : _POSTMORTEMSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.PostMortemSpec)
  })
_sym_db.RegisterMessage(PostMortemSpec)

PostMortemStatus = _reflection.GeneratedProtocolMessageType('PostMortemStatus', (_message.Message,), {
  'DESCRIPTOR' : _POSTMORTEMSTATUS,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.PostMortemStatus)
  })
_sym_db.RegisterMessage(PostMortemStatus)

RaisedAlert = _reflection.GeneratedProtocolMessageType('RaisedAlert', (_message.Message,), {
  'DESCRIPTOR' : _RAISEDALERT,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.RaisedAlert)
  })
_sym_db.RegisterMessage(RaisedAlert)

Review = _reflection.GeneratedProtocolMessageType('Review', (_message.Message,), {
  'DESCRIPTOR' : _REVIEW,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.Review)
  })
_sym_db.RegisterMessage(Review)

ReviewCondition = _reflection.GeneratedProtocolMessageType('ReviewCondition', (_message.Message,), {
  'DESCRIPTOR' : _REVIEWCONDITION,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.ReviewCondition)
  })
_sym_db.RegisterMessage(ReviewCondition)

ReviewList = _reflection.GeneratedProtocolMessageType('ReviewList', (_message.Message,), {
  'DESCRIPTOR' : _REVIEWLIST,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.ReviewList)
  })
_sym_db.RegisterMessage(ReviewList)

ReviewSpec = _reflection.GeneratedProtocolMessageType('ReviewSpec', (_message.Message,), {
  'DESCRIPTOR' : _REVIEWSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.ReviewSpec)
  })
_sym_db.RegisterMessage(ReviewSpec)

ReviewStatus = _reflection.GeneratedProtocolMessageType('ReviewStatus', (_message.Message,), {
  'DESCRIPTOR' : _REVIEWSTATUS,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.ReviewStatus)
  })
_sym_db.RegisterMessage(ReviewStatus)

RunBook = _reflection.GeneratedProtocolMessageType('RunBook', (_message.Message,), {
  'DESCRIPTOR' : _RUNBOOK,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.RunBook)
  })
_sym_db.RegisterMessage(RunBook)

RunBookCondition = _reflection.GeneratedProtocolMessageType('RunBookCondition', (_message.Message,), {
  'DESCRIPTOR' : _RUNBOOKCONDITION,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.RunBookCondition)
  })
_sym_db.RegisterMessage(RunBookCondition)

RunBookList = _reflection.GeneratedProtocolMessageType('RunBookList', (_message.Message,), {
  'DESCRIPTOR' : _RUNBOOKLIST,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.RunBookList)
  })
_sym_db.RegisterMessage(RunBookList)

RunBookSpec = _reflection.GeneratedProtocolMessageType('RunBookSpec', (_message.Message,), {
  'DESCRIPTOR' : _RUNBOOKSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.RunBookSpec)
  })
_sym_db.RegisterMessage(RunBookSpec)

RunBookStatus = _reflection.GeneratedProtocolMessageType('RunBookStatus', (_message.Message,), {
  'DESCRIPTOR' : _RUNBOOKSTATUS,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.RunBookStatus)
  })
_sym_db.RegisterMessage(RunBookStatus)

TimeLineEvent = _reflection.GeneratedProtocolMessageType('TimeLineEvent', (_message.Message,), {
  'DESCRIPTOR' : _TIMELINEEVENT,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.TimeLineEvent)
  })
_sym_db.RegisterMessage(TimeLineEvent)

Todo = _reflection.GeneratedProtocolMessageType('Todo', (_message.Message,), {
  'DESCRIPTOR' : _TODO,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.Todo)
  })
_sym_db.RegisterMessage(Todo)

TodoCondition = _reflection.GeneratedProtocolMessageType('TodoCondition', (_message.Message,), {
  'DESCRIPTOR' : _TODOCONDITION,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.TodoCondition)
  })
_sym_db.RegisterMessage(TodoCondition)

TodoList = _reflection.GeneratedProtocolMessageType('TodoList', (_message.Message,), {
  'DESCRIPTOR' : _TODOLIST,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.TodoList)
  })
_sym_db.RegisterMessage(TodoList)

TodoSpec = _reflection.GeneratedProtocolMessageType('TodoSpec', (_message.Message,), {
  'DESCRIPTOR' : _TODOSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.TodoSpec)
  })
_sym_db.RegisterMessage(TodoSpec)

TodoStatus = _reflection.GeneratedProtocolMessageType('TodoStatus', (_message.Message,), {
  'DESCRIPTOR' : _TODOSTATUS,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.TodoStatus)
  })
_sym_db.RegisterMessage(TodoStatus)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z4github.com/metaprov/modelaapi/pkg/apis/team/v1alpha1'
  _CHECKLISTITEM._serialized_start=321
  _CHECKLISTITEM._serialized_end=431
  _COMMENT._serialized_start=434
  _COMMENT._serialized_end=708
  _MEETING._serialized_start=711
  _MEETING._serialized_end=954
  _MEETINGCONDITION._serialized_start=957
  _MEETINGCONDITION._serialized_end=1110
  _MEETINGLIST._serialized_start=1113
  _MEETINGLIST._serialized_end=1270
  _MEETINGSPEC._serialized_start=1273
  _MEETINGSPEC._serialized_end=1558
  _MEETINGSTATUS._serialized_start=1561
  _MEETINGSTATUS._serialized_end=1812
  _POSTMORTEM._serialized_start=1815
  _POSTMORTEM._serialized_end=2067
  _POSTMORTEMCONDITION._serialized_start=2070
  _POSTMORTEMCONDITION._serialized_end=2226
  _POSTMORTEMLIST._serialized_start=2229
  _POSTMORTEMLIST._serialized_end=2392
  _POSTMORTEMSPEC._serialized_start=2395
  _POSTMORTEMSPEC._serialized_end=2878
  _POSTMORTEMSTATUS._serialized_start=2881
  _POSTMORTEMSTATUS._serialized_end=3087
  _RAISEDALERT._serialized_start=3089
  _RAISEDALERT._serialized_end=3172
  _REVIEW._serialized_start=3175
  _REVIEW._serialized_end=3415
  _REVIEWCONDITION._serialized_start=3418
  _REVIEWCONDITION._serialized_end=3570
  _REVIEWLIST._serialized_start=3573
  _REVIEWLIST._serialized_end=3728
  _REVIEWSPEC._serialized_start=3731
  _REVIEWSPEC._serialized_end=3973
  _REVIEWSTATUS._serialized_start=3976
  _REVIEWSTATUS._serialized_end=4174
  _RUNBOOK._serialized_start=4177
  _RUNBOOK._serialized_end=4420
  _RUNBOOKCONDITION._serialized_start=4423
  _RUNBOOKCONDITION._serialized_end=4644
  _RUNBOOKLIST._serialized_start=4647
  _RUNBOOKLIST._serialized_end=4804
  _RUNBOOKSPEC._serialized_start=4807
  _RUNBOOKSPEC._serialized_end=5112
  _RUNBOOKSTATUS._serialized_start=5115
  _RUNBOOKSTATUS._serialized_end=5315
  _TIMELINEEVENT._serialized_start=5317
  _TIMELINEEVENT._serialized_end=5405
  _TODO._serialized_start=5408
  _TODO._serialized_end=5642
  _TODOCONDITION._serialized_start=5645
  _TODOCONDITION._serialized_end=5795
  _TODOLIST._serialized_start=5798
  _TODOLIST._serialized_end=5949
  _TODOSPEC._serialized_start=5952
  _TODOSPEC._serialized_end=6311
  _TODOSTATUS._serialized_start=6314
  _TODOSTATUS._serialized_end=6523
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: k8s.io/apimachinery/pkg/runtime/generated.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/k8s.io/apimachinery/pkg/runtime/generated.proto\x12\x1fk8s.io.apimachinery.pkg.runtime\"\x1b\n\x0cRawExtension\x12\x0b\n\x03raw\x18\x01 \x01(\x0c\",\n\x08TypeMeta\x12\x12\n\napiVersion\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\"\x81\x01\n\x07Unknown\x12;\n\x08typeMeta\x18\x01 \x01(\x0b\x32).k8s.io.apimachinery.pkg.runtime.TypeMeta\x12\x0b\n\x03raw\x18\x02 \x01(\x0c\x12\x17\n\x0f\x63ontentEncoding\x18\x03 \x01(\t\x12\x13\n\x0b\x63ontentType\x18\x04 \x01(\tB!Z\x1fk8s.io/apimachinery/pkg/runtime')



_RAWEXTENSION = DESCRIPTOR.message_types_by_name['RawExtension']
_TYPEMETA = DESCRIPTOR.message_types_by_name['TypeMeta']
_UNKNOWN = DESCRIPTOR.message_types_by_name['Unknown']
RawExtension = _reflection.GeneratedProtocolMessageType('RawExtension', (_message.Message,), {
  'DESCRIPTOR' : _RAWEXTENSION,
  '__module__' : 'k8s.io.apimachinery.pkg.runtime.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.apimachinery.pkg.runtime.RawExtension)
  })
_sym_db.RegisterMessage(RawExtension)

TypeMeta = _reflection.GeneratedProtocolMessageType('TypeMeta', (_message.Message,), {
  'DESCRIPTOR' : _TYPEMETA,
  '__module__' : 'k8s.io.apimachinery.pkg.runtime.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.apimachinery.pkg.runtime.TypeMeta)
  })
_sym_db.RegisterMessage(TypeMeta)

Unknown = _reflection.GeneratedProtocolMessageType('Unknown', (_message.Message,), {
  'DESCRIPTOR' : _UNKNOWN,
  '__module__' : 'k8s.io.apimachinery.pkg.runtime.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.apimachinery.pkg.runtime.Unknown)
  })
_sym_db.RegisterMessage(Unknown)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\037k8s.io/apimachinery/pkg/runtime'
  _RAWEXTENSION._serialized_start=84
  _RAWEXTENSION._serialized_end=111
  _TYPEMETA._serialized_start=113
  _TYPEMETA._serialized_end=157
  _UNKNOWN._serialized_start=160
  _UNKNOWN._serialized_end=289
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from github.com.metaprov.modelaapi.services.curtain.v1 import curtain_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_curtain_dot_v1_dot_curtain__pb2


class CurtainServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListCurtains = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.curtain.v1.CurtainService/ListCurtains',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_curtain_dot_v1_dot_curtain__pb2.ListCurtainsRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_curtain_dot_v1_dot_curtain__pb2.ListCurtainsResponse.FromString,
                )
        self.CreateCurtain = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.curtain.v1.CurtainService/CreateCurtain',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_curtain_dot_v1_dot_curtain__pb2.CreateCurtainRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_curtain_dot_v1_dot_curtain__pb2.CreateCurtainResponse.FromString,
                )
        self.GetCurtain = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.curtain.v1.CurtainService/GetCurtain',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_curtain_dot_v1_dot_curtain__pb2.GetCurtainRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_curtain_dot_v1_dot_curtain__pb2.GetCurtainResponse.FromString,
                )
        self.UpdateCurtain = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.curtain.v1.CurtainService/UpdateCurtain',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_curtain_dot_v1_dot_curtain__pb2.UpdateCurtainRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_curtain_dot_v1_dot_curtain__pb2.UpdateCurtainResponse.FromString,
                )
        self.DeleteCurtain = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.curtain.v1.CurtainService/DeleteCurtain',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_curtain_dot_v1_dot_curtain__pb2.DeleteCurtainRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_curtain_dot_v1_dot_curtain__pb2.DeleteCurtainResponse.FromString,
                )


class CurtainServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListCurtains(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateCurtain(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetCurtain(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateCurtain(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteCurtain(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_CurtainServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListCurtains': grpc.unary_unary_rpc_method_handler(
                    servicer.ListCurtains,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_curtain_dot_v1_dot_curtain__pb2.ListCurtainsRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_curtain_dot_v1_dot_curtain__pb2.ListCurtainsResponse.SerializeToString,
            ),
            'CreateCurtain': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateCurtain,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_curtain_dot_v1_dot_curtain__pb2.CreateCurtainRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_curtain_dot_v1_dot_curtain__pb2.CreateCurtainResponse.SerializeToString,
            ),
            'GetCurtain': grpc.unary_unary_rpc_method_handler(
                    servicer.GetCurtain,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_curtain_dot_v1_dot_curtain__pb2.GetCurtainRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_curtain_dot_v1_dot_curtain__pb2.GetCurtainResponse.SerializeToString,
            ),
            'UpdateCurtain': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateCurtain,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_curtain_dot_v1_dot_curtain__pb2.UpdateCurtainRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_curtain_dot_v1_dot_curtain__pb2.UpdateCurtainResponse.SerializeToString,
            ),
            'DeleteCurtain': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteCurtain,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_curtain_dot_v1_dot_curtain__pb2.DeleteCurtainRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_curtain_dot_v1_dot_curtain__pb2.DeleteCurtainResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'github.com.metaprov.modelaapi.services.curtain.v1.CurtainService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class CurtainService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListCurtains(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.curtain.v1.CurtainService/ListCurtains',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_curtain_dot_v1_dot_curtain__pb2.ListCurtainsRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_curtain_dot_v1_dot_curtain__pb2.ListCurtainsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateCurtain(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.curtain.v1.CurtainService/CreateCurtain',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_curtain_dot_v1_dot_curtain__pb2.CreateCurtainRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_curtain_dot_v1_dot_curtain__pb2.CreateCurtainResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetCurtain(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.curtain.v1.CurtainService/GetCurtain',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_curtain_dot_v1_dot_curtain__pb2.GetCurtainRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_curtain_dot_v1_dot_curtain__pb2.GetCurtainResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateCurtain(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.curtain.v1.CurtainService/UpdateCurtain',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_curtain_dot_v1_dot_curtain__pb2.UpdateCurtainRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_curtain_dot_v1_dot_curtain__pb2.UpdateCurtainResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteCurtain(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.curtain.v1.CurtainService/DeleteCurtain',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_curtain_dot_v1_dot_curtain__pb2.DeleteCurtainRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_curtain_dot_v1_dot_curtain__pb2.DeleteCurtainResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/todo/v1/todo.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_team_dot_v1alpha1_dot_generated__pb2
from github.com.metaprov.modelaapi.services.common.v1 import common_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_common_dot_v1_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n9github.com/metaprov/modelaapi/services/todo/v1/todo.proto\x12.github.com.metaprov.modelaapi.services.todo.v1\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x44github.com/metaprov/modelaapi/pkg/apis/team/v1alpha1/generated.proto\x1a=github.com/metaprov/modelaapi/services/common/v1/common.proto\"\xb2\x01\n\x10ListTodosRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\\\n\x06labels\x18\x02 \x03(\x0b\x32L.github.com.metaprov.modelaapi.services.todo.v1.ListTodosRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"{\n\x11ListTodosResponse\x12M\n\x05todos\x18\x01 \x01(\x0b\x32>.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.TodoList\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"o\n\x11\x43reateTodoRequest\x12H\n\x04todo\x18\x01 \x01(\x0b\x32:.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.Todo\x12\x10\n\x08password\x18\x02 \x01(\t\"\x14\n\x12\x43reateTodoResponse\"\x8d\x01\n\x11UpdateTodoRequest\x12H\n\x04todo\x18\x01 \x01(\x0b\x32:.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.Todo\x12.\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"\x14\n\x12UpdateTodoResponse\"1\n\x0eGetTodoRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"i\n\x0fGetTodoResponse\x12H\n\x04todo\x18\x01 \x01(\x0b\x32:.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.Todo\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"4\n\x11\x44\x65leteTodoRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x14\n\x12\x44\x65leteTodoResponse2\xb5\x07\n\x0bTodoService\x12\xaf\x01\n\tListTodos\x12@.github.com.metaprov.modelaapi.services.todo.v1.ListTodosRequest\x1a\x41.github.com.metaprov.modelaapi.services.todo.v1.ListTodosResponse\"\x1d\x82\xd3\xe4\x93\x02\x17\x12\x15/v1/todos/{namespace}\x12\xa9\x01\n\nCreateTodo\x12\x41.github.com.metaprov.modelaapi.services.todo.v1.CreateTodoRequest\x1a\x42.github.com.metaprov.modelaapi.services.todo.v1.CreateTodoResponse\"\x14\x82\xd3\xe4\x93\x02\x0e\"\t/v1/todos:\x01*\x12\xb0\x01\n\x07GetTodo\x12>.github.com.metaprov.modelaapi.services.todo.v1.GetTodoRequest\x1a?.github.com.metaprov.modelaapi.services.todo.v1.GetTodoResponse\"$\x82\xd3\xe4\x93\x02\x1e\x12\x1c/v1/todos/{namespace}/{name}\x12\xd8\x01\n\nUpdateTodo\x12\x41.github.com.metaprov.modelaapi.services.todo.v1.UpdateTodoRequest\x1a\x42.github.com.metaprov.modelaapi.services.todo.v1.UpdateTodoResponse\"C\x82\xd3\xe4\x93\x02=\x1a\x38/v1/todos/{todo.metadata.namespace}/{todo.metadata.name}:\x01*\x12\xb9\x01\n\nDeleteTodo\x12\x41.github.com.metaprov.modelaapi.services.todo.v1.DeleteTodoRequest\x1a\x42.github.com.metaprov.modelaapi.services.todo.v1.DeleteTodoResponse\"$\x82\xd3\xe4\x93\x02\x1e*\x1c/v1/todos/{namespace}/{name}B0Z.github.com/metaprov/modelaapi/services/todo/v1b\x06proto3')



_LISTTODOSREQUEST = DESCRIPTOR.message_types_by_name['ListTodosRequest']
_LISTTODOSREQUEST_LABELSENTRY = _LISTTODOSREQUEST.nested_types_by_name['LabelsEntry']
_LISTTODOSRESPONSE = DESCRIPTOR.message_types_by_name['ListTodosResponse']
_CREATETODOREQUEST = DESCRIPTOR.message_types_by_name['CreateTodoRequest']
_CREATETODORESPONSE = DESCRIPTOR.message_types_by_name['CreateTodoResponse']
_UPDATETODOREQUEST = DESCRIPTOR.message_types_by_name['UpdateTodoRequest']
_UPDATETODORESPONSE = DESCRIPTOR.message_types_by_name['UpdateTodoResponse']
_GETTODOREQUEST = DESCRIPTOR.message_types_by_name['GetTodoRequest']
_GETTODORESPONSE = DESCRIPTOR.message_types_by_name['GetTodoResponse']
_DELETETODOREQUEST = DESCRIPTOR.message_types_by_name['DeleteTodoRequest']
_DELETETODORESPONSE = DESCRIPTOR.message_types_by_name['DeleteTodoResponse']
ListTodosRequest = _reflection.GeneratedProtocolMessageType('ListTodosRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTTODOSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.todo.v1.todo_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.todo.v1.ListTodosRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTTODOSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.todo.v1.todo_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.todo.v1.ListTodosRequest)
  })
_sym_db.RegisterMessage(ListTodosRequest)
_sym_db.RegisterMessage(ListTodosRequest.LabelsEntry)

ListTodosResponse = _reflection.GeneratedProtocolMessageType('ListTodosResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTTODOSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.todo.v1.todo_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.todo.v1.ListTodosResponse)
  })
_sym_db.RegisterMessage(ListTodosResponse)

CreateTodoRequest = _reflection.GeneratedProtocolMessageType('CreateTodoRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATETODOREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.todo.v1.todo_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.todo.v1.CreateTodoRequest)
  })
_sym_db.RegisterMessage(CreateTodoRequest)

CreateTodoResponse = _reflection.GeneratedProtocolMessageType('CreateTodoResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATETODORESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.todo.v1.todo_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.todo.v1.CreateTodoResponse)
  })
_sym_db.RegisterMessage(CreateTodoResponse)

UpdateTodoRequest = _reflection.GeneratedProtocolMessageType('UpdateTodoRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATETODOREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.todo.v1.todo_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.todo.v1.UpdateTodoRequest)
  })
_sym_db.RegisterMessage(UpdateTodoRequest)

UpdateTodoResponse = _reflection.GeneratedProtocolMessageType('UpdateTodoResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATETODORESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.todo.v1.todo_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.todo.v1.UpdateTodoResponse)
  })
_sym_db.RegisterMessage(UpdateTodoResponse)

GetTodoRequest = _reflection.GeneratedProtocolMessageType('GetTodoRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETTODOREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.todo.v1.todo_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.todo.v1.GetTodoRequest)
  })
_sym_db.RegisterMessage(GetTodoRequest)

GetTodoResponse = _reflection.GeneratedProtocolMessageType('GetTodoResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETTODORESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.todo.v1.todo_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.todo.v1.GetTodoResponse)
  })
_sym_db.RegisterMessage(GetTodoResponse)

DeleteTodoRequest = _reflection.GeneratedProtocolMessageType('DeleteTodoRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETETODOREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.todo.v1.todo_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.todo.v1.DeleteTodoRequest)
  })
_sym_db.RegisterMessage(DeleteTodoRequest)

DeleteTodoResponse = _reflection.GeneratedProtocolMessageType('DeleteTodoResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETETODORESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.todo.v1.todo_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.todo.v1.DeleteTodoResponse)
  })
_sym_db.RegisterMessage(DeleteTodoResponse)

_TODOSERVICE = DESCRIPTOR.services_by_name['TodoService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z.github.com/metaprov/modelaapi/services/todo/v1'
  _LISTTODOSREQUEST_LABELSENTRY._options = None
  _LISTTODOSREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _TODOSERVICE.methods_by_name['ListTodos']._options = None
  _TODOSERVICE.methods_by_name['ListTodos']._serialized_options = b'\202\323\344\223\002\027\022\025/v1/todos/{namespace}'
  _TODOSERVICE.methods_by_name['CreateTodo']._options = None
  _TODOSERVICE.methods_by_name['CreateTodo']._serialized_options = b'\202\323\344\223\002\016\"\t/v1/todos:\001*'
  _TODOSERVICE.methods_by_name['GetTodo']._options = None
  _TODOSERVICE.methods_by_name['GetTodo']._serialized_options = b'\202\323\344\223\002\036\022\034/v1/todos/{namespace}/{name}'
  _TODOSERVICE.methods_by_name['UpdateTodo']._options = None
  _TODOSERVICE.methods_by_name['UpdateTodo']._serialized_options = b'\202\323\344\223\002=\0328/v1/todos/{todo.metadata.namespace}/{todo.metadata.name}:\001*'
  _TODOSERVICE.methods_by_name['DeleteTodo']._options = None
  _TODOSERVICE.methods_by_name['DeleteTodo']._serialized_options = b'\202\323\344\223\002\036*\034/v1/todos/{namespace}/{name}'
  _LISTTODOSREQUEST._serialized_start=307
  _LISTTODOSREQUEST._serialized_end=485
  _LISTTODOSREQUEST_LABELSENTRY._serialized_start=440
  _LISTTODOSREQUEST_LABELSENTRY._serialized_end=485
  _LISTTODOSRESPONSE._serialized_start=487
  _LISTTODOSRESPONSE._serialized_end=610
  _CREATETODOREQUEST._serialized_start=612
  _CREATETODOREQUEST._serialized_end=723
  _CREATETODORESPONSE._serialized_start=725
  _CREATETODORESPONSE._serialized_end=745
  _UPDATETODOREQUEST._serialized_start=748
  _UPDATETODOREQUEST._serialized_end=889
  _UPDATETODORESPONSE._serialized_start=891
  _UPDATETODORESPONSE._serialized_end=911
  _GETTODOREQUEST._serialized_start=913
  _GETTODOREQUEST._serialized_end=962
  _GETTODORESPONSE._serialized_start=964
  _GETTODORESPONSE._serialized_end=1069
  _DELETETODOREQUEST._serialized_start=1071
  _DELETETODOREQUEST._serialized_end=1123
  _DELETETODORESPONSE._serialized_start=1125
  _DELETETODORESPONSE._serialized_end=1145
  _TODOSERVICE._serialized_start=1148
  _TODOSERVICE._serialized_end=2097
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/datapipelinerun/v1/datapipelinerun.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nOgithub.com/metaprov/modelaapi/services/datapipelinerun/v1/datapipelinerun.proto\x12\x39github.com.metaprov.modelaapi.services.datapipelinerun.v1\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x44github.com/metaprov/modelaapi/pkg/apis/data/v1alpha1/generated.proto\"\x8a\x02\n\x1aListDataPipelineRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12q\n\x06labels\x18\x02 \x03(\x0b\x32\x61.github.com.metaprov.modelaapi.services.datapipelinerun.v1.ListDataPipelineRunRequest.LabelsEntry\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\x12\n\npage_token\x18\x04 \x01(\t\x12\x10\n\x08order_by\x18\x05 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x9b\x01\n\x1bListDataPipelineRunResponse\x12\x63\n\x10\x64\x61tapipelineruns\x18\x01 \x01(\x0b\x32I.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataPipelineRunList\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"~\n\x1c\x43reateDataPipelineRunRequest\x12^\n\x0f\x64\x61tapipelinerun\x18\x01 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataPipelineRun\"\x1f\n\x1d\x43reateDataPipelineRunResponse\"\xae\x01\n\x1cUpdateDataPipelineRunRequest\x12^\n\x0f\x64\x61tapipelinerun\x18\x01 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataPipelineRun\x12.\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"\x1f\n\x1dUpdateDataPipelineRunResponse\"<\n\x19GetDataPipelineRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x8a\x01\n\x1aGetDataPipelineRunResponse\x12^\n\x0f\x64\x61tapipelinerun\x18\x01 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataPipelineRun\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"?\n\x1c\x44\x65leteDataPipelineRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x1f\n\x1d\x44\x65leteDataPipelineRunResponse\"\x1e\n\x1c\x41\x62ortDataPipelineRunResponse\">\n\x1b\x41\x62ortDataPipelineRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x1e\n\x1cPauseDataPipelineRunResponse\">\n\x1bPauseDataPipelineRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x1f\n\x1dResumeDataPipelineRunResponse\"?\n\x1cResumeDataPipelineRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t2\xa3\x10\n\x16\x44\x61taPipelineRunService\x12\xef\x01\n\x14ListDataPipelineRuns\x12U.github.com.metaprov.modelaapi.services.datapipelinerun.v1.ListDataPipelineRunRequest\x1aV.github.com.metaprov.modelaapi.services.datapipelinerun.v1.ListDataPipelineRunResponse\"(\x82\xd3\xe4\x93\x02\"\x12 /v1/datapipelineruns/{namespace}\x12\xeb\x01\n\x15\x43reateDataPipelineRun\x12W.github.com.metaprov.modelaapi.services.datapipelinerun.v1.CreateDataPipelineRunRequest\x1aX.github.com.metaprov.modelaapi.services.datapipelinerun.v1.CreateDataPipelineRunResponse\"\x1f\x82\xd3\xe4\x93\x02\x19\"\x14/v1/datapipelineruns:\x01*\x12\xf2\x01\n\x12GetDataPipelineRun\x12T.github.com.metaprov.modelaapi.services.datapipelinerun.v1.GetDataPipelineRunRequest\x1aU.github.com.metaprov.modelaapi.services.datapipelinerun.v1.GetDataPipelineRunResponse\"/\x82\xd3\xe4\x93\x02)\x12\'/v1/datapipelineruns/{namespace}/{name}\x12\xb0\x02\n\x15UpdateDataPipelineRun\x12W.github.com.metaprov.modelaapi.services.datapipelinerun.v1.UpdateDataPipelineRunRequest\x1aX.github.com.metaprov.modelaapi.services.datapipelinerun.v1.UpdateDataPipelineRunResponse\"d\x82\xd3\xe4\x93\x02^\x1aY/v1/datapipelineruns/{datapipelinerun.metadata.namespace}/{datapipelinerun.metadata.name}:\x01*\x12\xff\x01\n\x15\x44\x65leteDataPipelineRun\x12W.github.com.metaprov.modelaapi.services.datapipelinerun.v1.DeleteDataPipelineRunRequest\x1aX.github.com.metaprov.modelaapi.services.datapipelinerun.v1.DeleteDataPipelineRunResponse\"3\x82\xd3\xe4\x93\x02-*+/api/v1/datapipelineruns/{namespace}/{name}\x12\xfe\x01\n\x14\x41\x62ortDataPipelineRun\x12V.github.com.metaprov.modelaapi.services.datapipelinerun.v1.AbortDataPipelineRunRequest\x1aW.github.com.metaprov.modelaapi.services.datapipelinerun.v1.AbortDataPipelineRunResponse\"5\x82\xd3\xe4\x93\x02/\"-/v1/datapipelineruns/{namespace}/{name}:abort\x12\xfb\x01\n\x14PauseDataPipelineRun\x12V.github.com.metaprov.modelaapi.services.datapipelinerun.v1.PauseDataPipelineRunRequest\x1aW.github.com.metaprov.modelaapi.services.datapipelinerun.v1.PauseDataPipelineRunResponse\"2\x82\xd3\xe4\x93\x02,\"*/v1/datapipelines/{namespace}/{name}:pause\x12\xff\x01\n\x15ResumeDataPipelineRun\x12W.github.com.metaprov.modelaapi.services.datapipelinerun.v1.ResumeDataPipelineRunRequest\x1aX.github.com.metaprov.modelaapi.services.datapipelinerun.v1.ResumeDataPipelineRunResponse\"3\x82\xd3\xe4\x93\x02-\"+/v1/datapipelines/{namespace}/{name}:resumeB;Z9github.com/metaprov/modelaapi/services/datapipelinerun/v1b\x06proto3')



_LISTDATAPIPELINERUNREQUEST = DESCRIPTOR.message_types_by_name['ListDataPipelineRunRequest']
_LISTDATAPIPELINERUNREQUEST_LABELSENTRY = _LISTDATAPIPELINERUNREQUEST.nested_types_by_name['LabelsEntry']
_LISTDATAPIPELINERUNRESPONSE = DESCRIPTOR.message_types_by_name['ListDataPipelineRunResponse']
_CREATEDATAPIPELINERUNREQUEST = DESCRIPTOR.message_types_by_name['CreateDataPipelineRunRequest']
_CREATEDATAPIPELINERUNRESPONSE = DESCRIPTOR.message_types_by_name['CreateDataPipelineRunResponse']
_UPDATEDATAPIPELINERUNREQUEST = DESCRIPTOR.message_types_by_name['UpdateDataPipelineRunRequest']
_UPDATEDATAPIPELINERUNRESPONSE = DESCRIPTOR.message_types_by_name['UpdateDataPipelineRunResponse']
_GETDATAPIPELINERUNREQUEST = DESCRIPTOR.message_types_by_name['GetDataPipelineRunRequest']
_GETDATAPIPELINERUNRESPONSE = DESCRIPTOR.message_types_by_name['GetDataPipelineRunResponse']
_DELETEDATAPIPELINERUNREQUEST = DESCRIPTOR.message_types_by_name['DeleteDataPipelineRunRequest']
_DELETEDATAPIPELINERUNRESPONSE = DESCRIPTOR.message_types_by_name['DeleteDataPipelineRunResponse']
_ABORTDATAPIPELINERUNRESPONSE = DESCRIPTOR.message_types_by_name['AbortDataPipelineRunResponse']
_ABORTDATAPIPELINERUNREQUEST = DESCRIPTOR.message_types_by_name['AbortDataPipelineRunRequest']
_PAUSEDATAPIPELINERUNRESPONSE = DESCRIPTOR.message_types_by_name['PauseDataPipelineRunResponse']
_PAUSEDATAPIPELINERUNREQUEST = DESCRIPTOR.message_types_by_name['PauseDataPipelineRunRequest']
_RESUMEDATAPIPELINERUNRESPONSE = DESCRIPTOR.message_types_by_name['ResumeDataPipelineRunResponse']
_RESUMEDATAPIPELINERUNREQUEST = DESCRIPTOR.message_types_by_name['ResumeDataPipelineRunRequest']
ListDataPipelineRunRequest = _reflection.GeneratedProtocolMessageType('ListDataPipelineRunRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTDATAPIPELINERUNREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.datapipelinerun.v1.datapipelinerun_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datapipelinerun.v1.ListDataPipelineRunRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTDATAPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.datapipelinerun.v1.datapipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datapipelinerun.v1.ListDataPipelineRunRequest)
  })
_sym_db.RegisterMessage(ListDataPipelineRunRequest)
_sym_db.RegisterMessage(ListDataPipelineRunRequest.LabelsEntry)

ListDataPipelineRunResponse = _reflection.GeneratedProtocolMessageType('ListDataPipelineRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTDATAPIPELINERUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.datapipelinerun.v1.datapipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datapipelinerun.v1.ListDataPipelineRunResponse)
  })
_sym_db.RegisterMessage(ListDataPipelineRunResponse)

CreateDataPipelineRunRequest = _reflection.GeneratedProtocolMessageType('CreateDataPipelineRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDATAPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.datapipelinerun.v1.datapipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datapipelinerun.v1.CreateDataPipelineRunRequest)
  })
_sym_db.RegisterMessage(CreateDataPipelineRunRequest)

CreateDataPipelineRunResponse = _reflection.GeneratedProtocolMessageType('CreateDataPipelineRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDATAPIPELINERUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.datapipelinerun.v1.datapipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datapipelinerun.v1.CreateDataPipelineRunResponse)
  })
_sym_db.RegisterMessage(CreateDataPipelineRunResponse)

UpdateDataPipelineRunRequest = _reflection.GeneratedProtocolMessageType('UpdateDataPipelineRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDATAPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.datapipelinerun.v1.datapipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datapipelinerun.v1.UpdateDataPipelineRunRequest)
  })
_sym_db.RegisterMessage(UpdateDataPipelineRunRequest)

UpdateDataPipelineRunResponse = _reflection.GeneratedProtocolMessageType('UpdateDataPipelineRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDATAPIPELINERUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.datapipelinerun.v1.datapipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datapipelinerun.v1.UpdateDataPipelineRunResponse)
  })
_sym_db.RegisterMessage(UpdateDataPipelineRunResponse)

GetDataPipelineRunRequest = _reflection.GeneratedProtocolMessageType('GetDataPipelineRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDATAPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.datapipelinerun.v1.datapipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datapipelinerun.v1.GetDataPipelineRunRequest)
  })
_sym_db.RegisterMessage(GetDataPipelineRunRequest)

GetDataPipelineRunResponse = _reflection.GeneratedProtocolMessageType('GetDataPipelineRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETDATAPIPELINERUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.datapipelinerun.v1.datapipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datapipelinerun.v1.GetDataPipelineRunResponse)
  })
_sym_db.RegisterMessage(GetDataPipelineRunResponse)

DeleteDataPipelineRunRequest = _reflection.GeneratedProtocolMessageType('DeleteDataPipelineRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEDATAPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.datapipelinerun.v1.datapipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datapipelinerun.v1.DeleteDataPipelineRunRequest)
  })
_sym_db.RegisterMessage(DeleteDataPipelineRunRequest)

DeleteDataPipelineRunResponse = _reflection.GeneratedProtocolMessageType('DeleteDataPipelineRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEDATAPIPELINERUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.datapipelinerun.v1.datapipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datapipelinerun.v1.DeleteDataPipelineRunResponse)
  })
_sym_db.RegisterMessage(DeleteDataPipelineRunResponse)

AbortDataPipelineRunResponse = _reflection.GeneratedProtocolMessageType('AbortDataPipelineRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _ABORTDATAPIPELINERUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.datapipelinerun.v1.datapipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datapipelinerun.v1.AbortDataPipelineRunResponse)
  })
_sym_db.RegisterMessage(AbortDataPipelineRunResponse)

AbortDataPipelineRunRequest = _reflection.GeneratedProtocolMessageType('AbortDataPipelineRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _ABORTDATAPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.datapipelinerun.v1.datapipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datapipelinerun.v1.AbortDataPipelineRunRequest)
  })
_sym_db.RegisterMessage(AbortDataPipelineRunRequest)

PauseDataPipelineRunResponse = _reflection.GeneratedProtocolMessageType('PauseDataPipelineRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _PAUSEDATAPIPELINERUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.datapipelinerun.v1.datapipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datapipelinerun.v1.PauseDataPipelineRunResponse)
  })
_sym_db.RegisterMessage(PauseDataPipelineRunResponse)

PauseDataPipelineRunRequest = _reflection.GeneratedProtocolMessageType('PauseDataPipelineRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _PAUSEDATAPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.datapipelinerun.v1.datapipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datapipelinerun.v1.PauseDataPipelineRunRequest)
  })
_sym_db.RegisterMessage(PauseDataPipelineRunRequest)

ResumeDataPipelineRunResponse = _reflection.GeneratedProtocolMessageType('ResumeDataPipelineRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _RESUMEDATAPIPELINERUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.datapipelinerun.v1.datapipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datapipelinerun.v1.ResumeDataPipelineRunResponse)
  })
_sym_db.RegisterMessage(ResumeDataPipelineRunResponse)

ResumeDataPipelineRunRequest = _reflection.GeneratedProtocolMessageType('ResumeDataPipelineRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _RESUMEDATAPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.datapipelinerun.v1.datapipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datapipelinerun.v1.ResumeDataPipelineRunRequest)
  })
_sym_db.RegisterMessage(ResumeDataPipelineRunRequest)

_DATAPIPELINERUNSERVICE = DESCRIPTOR.services_by_name['DataPipelineRunService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z9github.com/metaprov/modelaapi/services/datapipelinerun/v1'
  _LISTDATAPIPELINERUNREQUEST_LABELSENTRY._options = None
  _LISTDATAPIPELINERUNREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _DATAPIPELINERUNSERVICE.methods_by_name['ListDataPipelineRuns']._options = None
  _DATAPIPELINERUNSERVICE.methods_by_name['ListDataPipelineRuns']._serialized_options = b'\202\323\344\223\002\"\022 /v1/datapipelineruns/{namespace}'
  _DATAPIPELINERUNSERVICE.methods_by_name['CreateDataPipelineRun']._options = None
  _DATAPIPELINERUNSERVICE.methods_by_name['CreateDataPipelineRun']._serialized_options = b'\202\323\344\223\002\031\"\024/v1/datapipelineruns:\001*'
  _DATAPIPELINERUNSERVICE.methods_by_name['GetDataPipelineRun']._options = None
  _DATAPIPELINERUNSERVICE.methods_by_name['GetDataPipelineRun']._serialized_options = b'\202\323\344\223\002)\022\'/v1/datapipelineruns/{namespace}/{name}'
  _DATAPIPELINERUNSERVICE.methods_by_name['UpdateDataPipelineRun']._options = None
  _DATAPIPELINERUNSERVICE.methods_by_name['UpdateDataPipelineRun']._serialized_options = b'\202\323\344\223\002^\032Y/v1/datapipelineruns/{datapipelinerun.metadata.namespace}/{datapipelinerun.metadata.name}:\001*'
  _DATAPIPELINERUNSERVICE.methods_by_name['DeleteDataPipelineRun']._options = None
  _DATAPIPELINERUNSERVICE.methods_by_name['DeleteDataPipelineRun']._serialized_options = b'\202\323\344\223\002-*+/api/v1/datapipelineruns/{namespace}/{name}'
  _DATAPIPELINERUNSERVICE.methods_by_name['AbortDataPipelineRun']._options = None
  _DATAPIPELINERUNSERVICE.methods_by_name['AbortDataPipelineRun']._serialized_options = b'\202\323\344\223\002/\"-/v1/datapipelineruns/{namespace}/{name}:abort'
  _DATAPIPELINERUNSERVICE.methods_by_name['PauseDataPipelineRun']._options = None
  _DATAPIPELINERUNSERVICE.methods_by_name['PauseDataPipelineRun']._serialized_options = b'\202\323\344\223\002,\"*/v1/datapipelines/{namespace}/{name}:pause'
  _DATAPIPELINERUNSERVICE.methods_by_name['ResumeDataPipelineRun']._options = None
  _DATAPIPELINERUNSERVICE.methods_by_name['ResumeDataPipelineRun']._serialized_options = b'\202\323\344\223\002-\"+/v1/datapipelines/{namespace}/{name}:resume'
  _LISTDATAPIPELINERUNREQUEST._serialized_start=277
  _LISTDATAPIPELINERUNREQUEST._serialized_end=543
  _LISTDATAPIPELINERUNREQUEST_LABELSENTRY._serialized_start=498
  _LISTDATAPIPELINERUNREQUEST_LABELSENTRY._serialized_end=543
  _LISTDATAPIPELINERUNRESPONSE._serialized_start=546
  _LISTDATAPIPELINERUNRESPONSE._serialized_end=701
  _CREATEDATAPIPELINERUNREQUEST._serialized_start=703
  _CREATEDATAPIPELINERUNREQUEST._serialized_end=829
  _CREATEDATAPIPELINERUNRESPONSE._serialized_start=831
  _CREATEDATAPIPELINERUNRESPONSE._serialized_end=862
  _UPDATEDATAPIPELINERUNREQUEST._serialized_start=865
  _UPDATEDATAPIPELINERUNREQUEST._serialized_end=1039
  _UPDATEDATAPIPELINERUNRESPONSE._serialized_start=1041
  _UPDATEDATAPIPELINERUNRESPONSE._serialized_end=1072
  _GETDATAPIPELINERUNREQUEST._serialized_start=1074
  _GETDATAPIPELINERUNREQUEST._serialized_end=1134
  _GETDATAPIPELINERUNRESPONSE._serialized_start=1137
  _GETDATAPIPELINERUNRESPONSE._serialized_end=1275
  _DELETEDATAPIPELINERUNREQUEST._serialized_start=1277
  _DELETEDATAPIPELINERUNREQUEST._serialized_end=1340
  _DELETEDATAPIPELINERUNRESPONSE._serialized_start=1342
  _DELETEDATAPIPELINERUNRESPONSE._serialized_end=1373
  _ABORTDATAPIPELINERUNRESPONSE._serialized_start=1375
  _ABORTDATAPIPELINERUNRESPONSE._serialized_end=1405
  _ABORTDATAPIPELINERUNREQUEST._serialized_start=1407
  _ABORTDATAPIPELINERUNREQUEST._serialized_end=1469
  _PAUSEDATAPIPELINERUNRESPONSE._serialized_start=1471
  _PAUSEDATAPIPELINERUNRESPONSE._serialized_end=1501
  _PAUSEDATAPIPELINERUNREQUEST._serialized_start=1503
  _PAUSEDATAPIPELINERUNREQUEST._serialized_end=1565
  _RESUMEDATAPIPELINERUNRESPONSE._serialized_start=1567
  _RESUMEDATAPIPELINERUNRESPONSE._serialized_end=1598
  _RESUMEDATAPIPELINERUNREQUEST._serialized_start=1600
  _RESUMEDATAPIPELINERUNREQUEST._serialized_end=1663
  _DATAPIPELINERUNSERVICE._serialized_start=1666
  _DATAPIPELINERUNSERVICE._serialized_end=3749
# @@protoc_insertion_point(module_scope)
